@@ -707,7 +707,7 @@ void DatabaseManager::encrypt (const QString a, QByteArray& b)
 {
 	unsigned char ivE[] = {0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15};
 
-	QByteArray t = a.toLocal8Bit();
+	QByteArray t = a.toUtf8();
 	int size = t.size();
 	int c = size / 16 + 1;
 	short p = 16 - size % 16;
@@ -745,9 +745,10 @@ void DatabaseManager::decrypt (const QByteArray& a, QString& b)
 	memcpy(pin, (unsigned char *)a.constData(), size);
 
 	AES_cbc_encrypt(pin, pout, c*16, &aeskeyD, ivD, AES_DECRYPT);
-	pout [size-(short)(pout[size-1])] = 0;
+	int ss = size-(short)(pout[size-1]);
+	pout [ss] = 0;
 
-	b = QString ((char*)pout);
+	b = QString::fromUtf8((char*)pout, ss);
 }
 
 void DatabaseManager::encrypt (const QByteArray& t, QByteArray& b)
